package client;

import javax.swing.*;
import java.awt.*;
import java.awt.event.*;
import java.net.*;
import java.io.*;
import java.util.*;

public class ChatClient extends JFrame {
	private JTextArea log;
	private JTextField input;
	private Socket socket;
	private OutputStream os;
	
	public static void main(String[] args) {
		InetAddress serverAddr = null;
		int serverPort = 0;
		try {
			serverAddr = InetAddress.getByName(args[0]);
			serverPort = Integer.parseInt(args[1]);
		} catch (Exception e) {
			System.err.println("Syntax: java client.ChatClient <server> <port>");
			System.exit(1);
		}
		try {
			Socket socket = new Socket(serverAddr, serverPort);
			new ChatClient(socket);
		} catch (Exception e) {
			System.err.println("Could not connect to server! Exiting...");
			System.exit(1);
		}
	}
	
	private ChatClient(Socket socket) {
		super("ChatClient");
		
		log = new JTextArea();
		log.setEditable(false);
		log.setFocusable(false);
		log.setLineWrap(true);
		log.setBackground(Color.BLACK);
		log.setForeground(Color.WHITE);
		add(log,BorderLayout.CENTER);
		
		input = new JTextField();
		input.addActionListener(new InputListener());
		add(input,BorderLayout.SOUTH);
		
		// Window close listener
		addWindowListener(new WindowAdapter() {
			public void windowClosing(WindowEvent e)
			{
				disconnect();
				System.exit(0);
			}
		});
		
        pack();

        input.requestFocusInWindow();
        
        setMinimumSize(new Dimension(640,480));
        setLocationRelativeTo(null);
        setVisible(true);
		
        try {
			this.socket = socket;
			this.os = socket.getOutputStream();
			new ReadThread(this,socket.getInputStream()).start();
		} catch (Exception e) {
			System.err.println("Failed to get OutputStream from Socket! Exiting...");
			System.exit(1);
		}
	}
	
	void log(String text) {
		log.append("[" + new Date() + "] " + text + "\n");
	}
	
	void disconnect() {
		try {
			socket.close();
		} catch (Exception e) {}
	}
	
	private class InputListener implements ActionListener {
		public void actionPerformed(ActionEvent arg0) {
			try {
				String text = input.getText();
				if (text.equals("/quit")) {
					os.write("Q:".getBytes());
					disconnect();
					System.exit(0);
				} else if (text.length() >= 5 && text.substring(0,5).equals("/name")) {
					if (text.length() >= 6) {
						os.write(("N:" + text.substring(6)).getBytes());
					} else {
						log("-- /name needs an argument!");
					}
				} else {
					text = "M:" + text;
					os.write(text.getBytes());
				}
				input.setText("");
			} catch (Exception e) {
				log("-- " + e.toString());
			}
		}
	}
}
