package server;

import java.net.*;
import java.util.*;

public class ChatServer {
	private Vector<Participant> participants = new Vector<Participant>();
	private Mailbox box;
		
	public static void main(String[] args) {
		new ChatServer(args);
	}
	
	private ChatServer(String[] args) {
		box = new Mailbox();
		int port = 0;
		try {
			port = Integer.parseInt(args[0]);
		} catch (Exception e) {
			System.out.println("Syntax: java server.ChatServer <port>");
		}
		        
		try{			
			ServerSocket server = new ServerSocket(port);
			new OutputThread(participants, box).start();
			
			while(true){
				Socket clientSocket = server.accept();
				String name;
				do {
					name = "Guest" + Math.round(Math.random() * 10000);
				} while (nameTaken(name));
				Participant part = new Participant(name, clientSocket);
				addPart(part);
				ParticipantThread partThread = new ParticipantThread(this, box, part);
				partThread.start();				
			}
			
			
		}catch (Exception e){
			e.printStackTrace();
		}		
	}

	void addPart(Participant part){
		participants.add(part);
		box.addMessage("E:\"" + part.getName() + "\" connected.");
	}
	
	void removePart(Participant part){
		box.addMessage("E:\"" + part.getName() + "\" disconnected.");
		participants.remove(part);
	}
	
	boolean nameTaken(String name) {
		for (Participant p : participants) {
			if (name.equals(p.getName())) {
				return true;
			}
		}
		return false;
	}
}
